/*

Copyright (C) 2000, 2001, 2002 Christian Kreibich <christian@whoop.org>.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies of the Software and its documentation and acknowledgment shall be
given in the documentation and software packages that this Software was
used.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/
#ifndef __netdude_dialog_h
#define __netdude_dialog_h

#include <gtk/gtk.h>
#include <netdude/nd_packet.h>

typedef enum {
  ND_DIALOG_QUESTION,
  ND_DIALOG_WARNING
} ND_DialogType;

typedef enum {
  ND_BASE_DEC,
  ND_BASE_HEX
} ND_Base;


typedef void (*ND_NumberCallback) (ND_Packet *packet,
				   void      *user_data,
				   guint      value);

typedef void (*ND_AddressCallback) (guchar    *address,
				    int        address_len,
				    ND_Packet *packet,
				    void      *user_data);

typedef void (*ND_FilenameCallback) (const char *filename,
				     void *user_data);

/* The signature of the generic callbacks used in the dialogs.
   Also used in the generic number and address dialogs for
   the "Cancel" callbacks, where the user can clean up any
   user_data if necessary. */
typedef void (*ND_DialogCallback) (void *user_data);


/* Shows a Yes-No-Cancel dialog and calls the appriopriate callback
   when a button is clicked. The dialog is displayed and hidden
   automatically. You can pass NULL for the callbacks. */
void      nd_dialog_ync(const char *title, const char *message,
			ND_DialogCallback yes_cb,
			ND_DialogCallback no_cb,
			ND_DialogCallback cancel_cb,
			void *user_data);

/* A simple message dialog with an okay button. No callbacks. */
void      nd_dialog_message(const char *title,
			    const char *message,
			    gboolean    modal);


/* Shows the generic number entry dialog, with the given label
   and initial value. The largest possible value is given through
   MAX. When the OK button is clicked, CALLBACK_OKAY is called with
   the new value, on cancel, CALLBACK_CANCEL is called. You can
   pass NULL for the latter if you don't need it.
*/
void      nd_dialog_number(const char *message,
			   ND_Base base,
			   guint value, guint max,
			   ND_NumberCallback callback_okay,
			   ND_DialogCallback callback_cancel,
			   ND_Packet *packet,
			   void *user_data);

void      nd_dialog_number_update(void);
void      nd_dialog_number_set_base(ND_Base base);
void      nd_dialog_number_ok(GtkWidget *dialog);
void      nd_dialog_number_cancel(GtkWidget *dialog);

/* GtkSpinButton is buggy for large values, at least in Gtk 1.2+.
 * These are callbacks for the replacement dialog. The user should
 * hardly notice any difference.
 */
void      nd_dialog_largenumber_ok(GtkWidget *dialog);
void      nd_dialog_largenumber_up(GtkWidget *dialog);
void      nd_dialog_largenumber_down(GtkWidget *dialog);


/* Shows the generic hardware address entry dialog, with the given length
   (in bytes, e.g. 6 for Ethernet. When the OK button is clicked,
   CALLBACK_OKAY is called with the new value. You can pass NULL
   for CALLBACK_CANCEL if you don't need it.
*/
void      nd_dialog_hardware_address(const char *message,
				     guchar *address, int address_len,
				     ND_AddressCallback callback_okay,
				     ND_DialogCallback  callback_cancel,
				     ND_Packet *packet,
				     void *user_data);

void      nd_dialog_ip(const char *message, guchar *ip_address,
		       ND_AddressCallback callback_ok,
		       ND_DialogCallback  callback_cancel,
		       ND_Packet *packet,
		       void *user_data);		       

void      nd_dialog_ip_ok(void);
void      nd_dialog_ip_cancel(void);


void      nd_dialog_filesel(const char *title,
			    const char *fname,
			    ND_FilenameCallback callback_fname,
			    void *user_data);
void      nd_dialog_filesel_close();
void      nd_dialog_filesel_ok(GtkWidget *dialog);


/* This opens the exit dialog, which shows a list of unsaved
   files, which you can save directly from the dialog before
   exiting. */
void      nd_dialog_exit(void);


/* This is the most generic way to generate a dialog, allowing you
   to basically specify all parts of it. The varargs specify the
   buttons and must be a sequence of char*s for buttons labels and
   ND_DialogCallbacks for the button callbacks. */
void      nd_dialog_generic(ND_DialogType  type,
			    const char    *title,
			    const char    *message,
			    gboolean       modal,
			    GtkWidget     *extra_area,
			    void          *user_data,
			    int            num_buttons,
			    ...);
		    

/* Shows the Netdude about dialog. */
void      nd_dialog_about(void);


typedef void (*ND_FontselCallback) (const char *fontname,
				    void *user_data);

void      nd_dialog_fontsel(const char *title, const char *fontname,
			    ND_FontselCallback callback_ok,
			    void *user_data);		       

void      nd_dialog_fontsel_ok(GtkFontSelectionDialog *dialog);
void      nd_dialog_fontsel_cancel(GtkFontSelectionDialog *dialog);
void      nd_dialog_fontsel_apply(GtkFontSelectionDialog *dialog);

#endif
